@@ -7,7 +7,7 @@ class XpathParserTypeError(Exception):
     def __str__(self):
         return repr("incorrect parser type")
 
-class ArgVauleError(Exception):
+class ArgValueError(Exception):
     def __init__(self, vaule):
         self.vaule = vaule
 
